@@ -5,7 +5,5 @@ use serde::{Deserialize, Serialize};
 #[serde(rename_all = "camelCase")]
 pub struct Configuration {
   pub line_width: u32,
-  pub use_tabs: bool,
-  pub indent_width: u8,
   pub new_line_kind: NewLineKind,
 }
